[Darshan-commits] [Darshan] branch, master, updated. darshan-2.3.1-pre2-6-g3cd66a9

Service Account git at mcs.anl.gov
Fri Mar 13 09:43:46 CDT 2015


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "".

The branch, master has been updated
       via  3cd66a93b5f8d2cb6725e5302f64da8163e6adce (commit)
      from  ef521fcb05fa0bfbea009efa98f1fcb2eff6a100 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 3cd66a93b5f8d2cb6725e5302f64da8163e6adce
Author: Phil Carns <carns at mcs.anl.gov>
Date:   Fri Mar 13 14:43:35 2015 +0000

    bluegend profile testing environment

-----------------------------------------------------------------------

Summary of changes:
 .../env.sh                                         |   15 ++++++-----
 darshan-test/regression/bg-profile-conf/runjob.sh  |   26 ++++++++++++++++++++
 2 files changed, 34 insertions(+), 7 deletions(-)
 copy darshan-test/regression/{workstation-profile-conf => bg-profile-conf}/env.sh (66%)
 create mode 100755 darshan-test/regression/bg-profile-conf/runjob.sh


Diff of changes:
diff --git a/darshan-test/regression/bg-profile-conf/runjob.sh b/darshan-test/regression/bg-profile-conf/runjob.sh
new file mode 100755
index 0000000..d21c8bb
--- /dev/null
+++ b/darshan-test/regression/bg-profile-conf/runjob.sh
@@ -0,0 +1,26 @@
+#!/bin/bash
+
+# submit job and get job id
+jobid=`qsub --mode c16 --proccount $DARSHAN_DEFAULT_NPROCS -A SSSPPg -t 10 -n 1 --output $DARSHAN_TMP/$$-tmp.out --error $DARSHAN_TMP/$$-tmp.err --debuglog $DARSHAN_TMP/$$-tmp.debuglog "$@"`
+if [ $? -ne 0 ]; then
+	echo "Error: failed to qsub $@"
+	exit 1
+fi
+
+output="foo"
+rc=0
+
+# loop as long as qstat succeeds and shows information about job
+while [ -n "$output" -a "$rc" -eq 0 ]; do
+	sleep 5
+	output=`qstat $jobid`
+	rc=$?
+done
+
+# look for return code
+grep "exit code of 0" $$-tmp.debuglog
+if [ $? -ne 0 ]; then
+	exit 1
+else
+	exit 0
+fi


hooks/post-receive
diff --git a/darshan-test/regression/workstation-profile-conf/env.sh b/darshan-test/regression/bg-profile-conf/env.sh
similarity index 66%
copy from darshan-test/regression/workstation-profile-conf/env.sh
copy to darshan-test/regression/bg-profile-conf/env.sh
index 0147783..df4f16b 100755
--- a/darshan-test/regression/workstation-profile-conf/env.sh
+++ b/darshan-test/regression/bg-profile-conf/env.sh
@@ -16,23 +16,24 @@
 # variables (as in a dynamically linked environment), or generate mpicc
 # wrappers (as in a statically linked environment).
 
 # Notes specific to this platform (workstation-dynamic)_
 ########################
 # This particular env script assumes that mpicc and its variants for other 
 # languages are already in the path, and that they will produce static 
 # executables by default.  Darshan instrumentation is added by specifying
 # a profiling configuration file using environment variables.
 
-# The runjob command is just mpiexec, no scheduler
+# the RUNJOB command is the most complex part here.  We use a script that submits
+# a cobalt job, waits for its completion, and checks its return status
 
 export DARSHAN_CC=mpicc
 export DARSHAN_CXX=mpicxx
 export DARSHAN_F77=mpif77
 export DARSHAN_F90=mpif90
 
-export MPICC_PROFILE=$DARSHAN_PATH/share/mpi-profile/darshan-cc
-export MPICXX_PROFILE=$DARSHAN_PATH/share/mpi-profile/darshan-cxx
-export MPIF90_PROFILE=$DARSHAN_PATH/share/mpi-profile/darshan-f
-export MPIF77_PROFILE=$DARSHAN_PATH/share/mpi-profile/darshan-f
+export MPICC_PROFILE=$DARSHAN_PATH/share/mpi-profile/darshan-bg-cc
+export MPICXX_PROFILE=$DARSHAN_PATH/share/mpi-profile/darshan-bg-cxx
+export MPIF90_PROFILE=$DARSHAN_PATH/share/mpi-profile/darshan-bg-f
+export MPIF77_PROFILE=$DARSHAN_PATH/share/mpi-profile/darshan-bg-f
 
-export DARSHAN_RUNJOB="mpiexec -n $DARSHAN_DEFAULT_NPROCS"
+export DARSHAN_RUNJOB="bg-profile-conf/runjob.sh"
@@ -16,23 +16,24 @@
 # wrappers (as in a statically linked environment).
 
-# Notes specific to this platform (workstation-dynamic)_
+# Notes specific to this platform (bg-profile-conf)
 ########################
 # This particular env script assumes that mpicc and its variants for other 
--



More information about the Darshan-commits mailing list